{% extends "socialaccount/authentication_error.html" %}
{% load i18n %}
{% load slippers %}
{% block content %}
    {% trans "Third-Party Login Failure" as heading %}
    {% trans "An error occurred while attempting to login via your third-party account." as subheading %}
    {% #container heading=heading subheading=subheading %}
    {% /container %}
{% endblock content %}
