{% extends "socialaccount/login.html" %}
{% load i18n %}
{% load slippers %}
{% load allauth %}
{% block content %}
    {% if process == "connect" %}
        {% blocktrans asvar heading with provider.name as provider %}Connect {{ provider }}{% endblocktrans %}
        {% blocktrans asvar subheading with provider.name as provider %}You are about to connect a new third-party account from {{ provider }}.{% endblocktrans %}
    {% else %}
        {% blocktrans asvar heading with provider.name as provider %}Sign In Via {{ provider }}{% endblocktrans %}
        {% blocktrans asvar subheading with provider.name as provider %}You are about to sign in using a third-party account from {{ provider }}.{% endblocktrans %}
    {% endif %}
    {% #container heading=heading subheading=subheading %}
    {% trans "Continue" as button_text %}
    {% #form button_text=button_text %}
    {% csrf_token %}
    {{ redirect_field }}
    {% /form %}
    {% /container %}
{% endblock content %}
