{% extends "account/password_reset_from_key_done.html" %}
{% load i18n %}
{% load slippers %}
{% block content %}
    {% trans "Change Password" as heading %}
    {% trans "Your password is now changed." as subheading %}
    {% #container heading=heading subheading=subheading %}
    {% /container %}
{% endblock content %}
